pub struct ExecResult { /* private fields */ }Expand description
Execution result for DML operations (INSERT, UPDATE, DELETE)
This result type tracks the number of rows affected and the last insert ID for auto-increment columns.
Implementations
Sourceimpl ExecResult
impl ExecResult
Sourcepub fn with_rows_affected(rows_affected: i64) -> Self
pub fn with_rows_affected(rows_affected: i64) -> Self
Create a result with just rows affected
Sourcepub fn with_last_insert_id(rows_affected: i64, last_insert_id: i64) -> Self
pub fn with_last_insert_id(rows_affected: i64, last_insert_id: i64) -> Self
Create a result with rows affected and last insert ID