pub struct LeadFunction { /* private fields */ }Expand description
LEAD window function
Returns the value from a row that is offset rows after the current row
within the partition. If there is no such row, returns the default value.
Implementations
Sourceimpl LeadFunction
impl LeadFunction